@@ -279,8 +279,7 @@ rd-img-top"/>
 
 ```
 """
-
-            with open(f"{dir_base}/content/mysite/map/{public_name}/gallery.ejs", "w") as resource_file:
+            with open(f"{dir_base}/content/mysite/gallery/{public_name}/gallery.ejs", "w") as resource_file:
                 resource_file.write(gallery_ejs)
 
             with open(f"{dir_base}/content/mysite/gallery/{public_name}/index.qmd", "w") as hugo_file:
